Clazz.declarePackage("J.adapter.readers.pymol");
Clazz.load(["java.lang.Enum"], "J.adapter.readers.pymol.PyMOLSettings", null, function(){
var c$ = Clazz.decorateAsClass(function(){
this.code = 0;
Clazz.instantialize(this, arguments);}, J.adapter.readers.pymol, "PyMOLSettings", Enum);
Clazz.makeConstructor(c$, 
function(code){
this.code = code;
}, "~N");
c$.getName = Clazz.defineMethod(c$, "getName", 
function(setting){
return J.adapter.readers.pymol.PyMOLSettings.names[setting];
}, "~N");
c$.names =  new Array(1000);
{
for (var p, $p = 0, $$p = J.adapter.readers.pymol.PyMOLSettings.values(); $p < $$p.length && ((p = $$p[$p]) || true); $p++) {
J.adapter.readers.pymol.PyMOLSettings.names[p.code] = p.toString();
}
}Clazz.defineEnumConstant(c$, "bonding_vdw_cutoff", 0, [0]);
Clazz.defineEnumConstant(c$, "min_mesh_spacing", 1, [1]);
Clazz.defineEnumConstant(c$, "dot_density", 2, [2]);
Clazz.defineEnumConstant(c$, "dot_mode", 3, [3]);
Clazz.defineEnumConstant(c$, "solvent_radius", 4, [4]);
Clazz.defineEnumConstant(c$, "sel_counter", 5, [5]);
Clazz.defineEnumConstant(c$, "bg_rgb", 6, [6]);
Clazz.defineEnumConstant(c$, "ambient", 7, [7]);
Clazz.defineEnumConstant(c$, "direct", 8, [8]);
Clazz.defineEnumConstant(c$, "reflect", 9, [9]);
Clazz.defineEnumConstant(c$, "light", 10, [10]);
Clazz.defineEnumConstant(c$, "power", 11, [11]);
Clazz.defineEnumConstant(c$, "antialias", 12, [12]);
Clazz.defineEnumConstant(c$, "cavity_cull", 13, [13]);
Clazz.defineEnumConstant(c$, "gl_ambient", 14, [14]);
Clazz.defineEnumConstant(c$, "single_image", 15, [15]);
Clazz.defineEnumConstant(c$, "movie_delay", 16, [16]);
Clazz.defineEnumConstant(c$, "ribbon_power", 17, [17]);
Clazz.defineEnumConstant(c$, "ribbon_power_b", 18, [18]);
Clazz.defineEnumConstant(c$, "ribbon_sampling", 19, [19]);
Clazz.defineEnumConstant(c$, "ribbon_radius", 20, [20]);
Clazz.defineEnumConstant(c$, "stick_radius", 21, [21]);
Clazz.defineEnumConstant(c$, "hash_max", 22, [22]);
Clazz.defineEnumConstant(c$, "orthoscopic", 23, [23]);
Clazz.defineEnumConstant(c$, "spec_reflect", 24, [24]);
Clazz.defineEnumConstant(c$, "spec_power", 25, [25]);
Clazz.defineEnumConstant(c$, "sweep_angle", 26, [26]);
Clazz.defineEnumConstant(c$, "sweep_speed", 27, [27]);
Clazz.defineEnumConstant(c$, "dot_hydrogens", 28, [28]);
Clazz.defineEnumConstant(c$, "dot_radius", 29, [29]);
Clazz.defineEnumConstant(c$, "ray_trace_frames", 30, [30]);
Clazz.defineEnumConstant(c$, "cache_frames", 31, [31]);
Clazz.defineEnumConstant(c$, "trim_dots", 32, [32]);
Clazz.defineEnumConstant(c$, "cull_spheres", 33, [33]);
Clazz.defineEnumConstant(c$, "test1", 34, [34]);
Clazz.defineEnumConstant(c$, "test2", 35, [35]);
Clazz.defineEnumConstant(c$, "surface_best", 36, [36]);
Clazz.defineEnumConstant(c$, "surface_normal", 37, [37]);
Clazz.defineEnumConstant(c$, "surface_quality", 38, [38]);
Clazz.defineEnumConstant(c$, "surface_proximity", 39, [39]);
Clazz.defineEnumConstant(c$, "normal_workaround", 40, [40]);
Clazz.defineEnumConstant(c$, "stereo_angle", 41, [41]);
Clazz.defineEnumConstant(c$, "stereo_shift", 42, [42]);
Clazz.defineEnumConstant(c$, "line_smooth", 43, [43]);
Clazz.defineEnumConstant(c$, "line_width", 44, [44]);
Clazz.defineEnumConstant(c$, "half_bonds", 45, [45]);
Clazz.defineEnumConstant(c$, "stick_quality", 46, [46]);
Clazz.defineEnumConstant(c$, "stick_overlap", 47, [47]);
Clazz.defineEnumConstant(c$, "stick_nub", 48, [48]);
Clazz.defineEnumConstant(c$, "all_states", 49, [49]);
Clazz.defineEnumConstant(c$, "pickable", 50, [50]);
Clazz.defineEnumConstant(c$, "auto_show_lines", 51, [51]);
Clazz.defineEnumConstant(c$, "idle_delay", 52, [52]);
Clazz.defineEnumConstant(c$, "no_idle", 53, [53]);
Clazz.defineEnumConstant(c$, "fast_idle", 54, [54]);
Clazz.defineEnumConstant(c$, "slow_idle", 55, [55]);
Clazz.defineEnumConstant(c$, "rock_delay", 56, [56]);
Clazz.defineEnumConstant(c$, "dist_counter", 57, [57]);
Clazz.defineEnumConstant(c$, "dash_length", 58, [58]);
Clazz.defineEnumConstant(c$, "dash_gap", 59, [59]);
Clazz.defineEnumConstant(c$, "auto_zoom", 60, [60]);
Clazz.defineEnumConstant(c$, "overlay", 61, [61]);
Clazz.defineEnumConstant(c$, "text", 62, [62]);
Clazz.defineEnumConstant(c$, "button_mode", 63, [63]);
Clazz.defineEnumConstant(c$, "valence", 64, [64]);
Clazz.defineEnumConstant(c$, "nonbonded_size", 65, [65]);
Clazz.defineEnumConstant(c$, "label_color", 66, [66]);
Clazz.defineEnumConstant(c$, "ray_trace_fog", 67, [67]);
Clazz.defineEnumConstant(c$, "spheroid_scale", 68, [68]);
Clazz.defineEnumConstant(c$, "ray_trace_fog_start", 69, [69]);
Clazz.defineEnumConstant(c$, "spheroid_smooth", 70, [70]);
Clazz.defineEnumConstant(c$, "spheroid_fill", 71, [71]);
Clazz.defineEnumConstant(c$, "auto_show_nonbonded", 72, [72]);
Clazz.defineEnumConstant(c$, "cache_display", 73, [73]);
Clazz.defineEnumConstant(c$, "mesh_radius", 74, [74]);
Clazz.defineEnumConstant(c$, "backface_cull", 75, [75]);
Clazz.defineEnumConstant(c$, "gamma", 76, [76]);
Clazz.defineEnumConstant(c$, "dot_width", 77, [77]);
Clazz.defineEnumConstant(c$, "auto_show_selections", 78, [78]);
Clazz.defineEnumConstant(c$, "auto_hide_selections", 79, [79]);
Clazz.defineEnumConstant(c$, "selection_width", 80, [80]);
Clazz.defineEnumConstant(c$, "selection_overlay", 81, [81]);
Clazz.defineEnumConstant(c$, "static_singletons", 82, [82]);
Clazz.defineEnumConstant(c$, "max_triangles", 83, [83]);
Clazz.defineEnumConstant(c$, "depth_cue", 84, [84]);
Clazz.defineEnumConstant(c$, "specular", 85, [85]);
Clazz.defineEnumConstant(c$, "shininess", 86, [86]);
Clazz.defineEnumConstant(c$, "sphere_quality", 87, [87]);
Clazz.defineEnumConstant(c$, "fog", 88, [88]);
Clazz.defineEnumConstant(c$, "isomesh_auto_state", 89, [89]);
Clazz.defineEnumConstant(c$, "mesh_width", 90, [90]);
Clazz.defineEnumConstant(c$, "cartoon_sampling", 91, [91]);
Clazz.defineEnumConstant(c$, "cartoon_loop_radius", 92, [92]);
Clazz.defineEnumConstant(c$, "cartoon_loop_quality", 93, [93]);
Clazz.defineEnumConstant(c$, "cartoon_power", 94, [94]);
Clazz.defineEnumConstant(c$, "cartoon_power_b", 95, [95]);
Clazz.defineEnumConstant(c$, "cartoon_rect_length", 96, [96]);
Clazz.defineEnumConstant(c$, "cartoon_rect_width", 97, [97]);
Clazz.defineEnumConstant(c$, "internal_gui_width", 98, [98]);
Clazz.defineEnumConstant(c$, "internal_gui", 99, [99]);
Clazz.defineEnumConstant(c$, "cartoon_oval_length", 100, [100]);
Clazz.defineEnumConstant(c$, "cartoon_oval_width", 101, [101]);
Clazz.defineEnumConstant(c$, "cartoon_oval_quality", 102, [102]);
Clazz.defineEnumConstant(c$, "cartoon_tube_radius", 103, [103]);
Clazz.defineEnumConstant(c$, "cartoon_tube_quality", 104, [104]);
Clazz.defineEnumConstant(c$, "cartoon_debug", 105, [105]);
Clazz.defineEnumConstant(c$, "ribbon_width", 106, [106]);
Clazz.defineEnumConstant(c$, "dash_width", 107, [107]);
Clazz.defineEnumConstant(c$, "dash_radius", 108, [108]);
Clazz.defineEnumConstant(c$, "cgo_ray_width_scale", 109, [109]);
Clazz.defineEnumConstant(c$, "line_radius", 110, [110]);
Clazz.defineEnumConstant(c$, "cartoon_round_helices", 111, [111]);
Clazz.defineEnumConstant(c$, "cartoon_refine_normals", 112, [112]);
Clazz.defineEnumConstant(c$, "cartoon_flat_sheets", 113, [113]);
Clazz.defineEnumConstant(c$, "cartoon_smooth_loops", 114, [114]);
Clazz.defineEnumConstant(c$, "cartoon_dumbbell_length", 115, [115]);
Clazz.defineEnumConstant(c$, "cartoon_dumbbell_width", 116, [116]);
Clazz.defineEnumConstant(c$, "cartoon_dumbbell_radius", 117, [117]);
Clazz.defineEnumConstant(c$, "cartoon_fancy_helices", 118, [118]);
Clazz.defineEnumConstant(c$, "cartoon_fancy_sheets", 119, [119]);
Clazz.defineEnumConstant(c$, "ignore_pdb_segi", 120, [120]);
Clazz.defineEnumConstant(c$, "ribbon_throw", 121, [121]);
Clazz.defineEnumConstant(c$, "cartoon_throw", 122, [122]);
Clazz.defineEnumConstant(c$, "cartoon_refine", 123, [123]);
Clazz.defineEnumConstant(c$, "cartoon_refine_tips", 124, [124]);
Clazz.defineEnumConstant(c$, "cartoon_discrete_colors", 125, [125]);
Clazz.defineEnumConstant(c$, "normalize_ccp4_maps", 126, [126]);
Clazz.defineEnumConstant(c$, "surface_poor", 127, [127]);
Clazz.defineEnumConstant(c$, "internal_feedback", 128, [128]);
Clazz.defineEnumConstant(c$, "cgo_line_width", 129, [129]);
Clazz.defineEnumConstant(c$, "cgo_line_radius", 130, [130]);
Clazz.defineEnumConstant(c$, "logging", 131, [131]);
Clazz.defineEnumConstant(c$, "robust_logs", 132, [132]);
Clazz.defineEnumConstant(c$, "log_box_selections", 133, [133]);
Clazz.defineEnumConstant(c$, "log_conformations", 134, [134]);
Clazz.defineEnumConstant(c$, "valence_size", 135, [135]);
Clazz.defineEnumConstant(c$, "surface_miserable", 136, [136]);
Clazz.defineEnumConstant(c$, "ray_opaque_background", 137, [137]);
Clazz.defineEnumConstant(c$, "transparency", 138, [138]);
Clazz.defineEnumConstant(c$, "ray_texture", 139, [139]);
Clazz.defineEnumConstant(c$, "ray_texture_settings", 140, [140]);
Clazz.defineEnumConstant(c$, "suspend_updates", 141, [141]);
Clazz.defineEnumConstant(c$, "full_screen", 142, [142]);
Clazz.defineEnumConstant(c$, "surface_mode", 143, [143]);
Clazz.defineEnumConstant(c$, "surface_color", 144, [144]);
Clazz.defineEnumConstant(c$, "mesh_mode", 145, [145]);
Clazz.defineEnumConstant(c$, "mesh_color", 146, [146]);
Clazz.defineEnumConstant(c$, "auto_indicate_flags", 147, [147]);
Clazz.defineEnumConstant(c$, "surface_debug", 148, [148]);
Clazz.defineEnumConstant(c$, "ray_improve_shadows", 149, [149]);
Clazz.defineEnumConstant(c$, "smooth_color_triangle", 150, [150]);
Clazz.defineEnumConstant(c$, "ray_default_renderer", 151, [151]);
Clazz.defineEnumConstant(c$, "field_of_view", 152, [152]);
Clazz.defineEnumConstant(c$, "reflect_power", 153, [153]);
Clazz.defineEnumConstant(c$, "preserve_chempy_ids", 154, [154]);
Clazz.defineEnumConstant(c$, "sphere_scale", 155, [155]);
Clazz.defineEnumConstant(c$, "two_sided_lighting", 156, [156]);
Clazz.defineEnumConstant(c$, "secondary_structure", 157, [157]);
Clazz.defineEnumConstant(c$, "auto_remove_hydrogens", 158, [158]);
Clazz.defineEnumConstant(c$, "raise_exceptions", 159, [159]);
Clazz.defineEnumConstant(c$, "stop_on_exceptions", 160, [160]);
Clazz.defineEnumConstant(c$, "sculpting", 161, [161]);
Clazz.defineEnumConstant(c$, "auto_sculpt", 162, [162]);
Clazz.defineEnumConstant(c$, "sculpt_vdw_scale", 163, [163]);
Clazz.defineEnumConstant(c$, "sculpt_vdw_scale14", 164, [164]);
Clazz.defineEnumConstant(c$, "sculpt_vdw_weight", 165, [165]);
Clazz.defineEnumConstant(c$, "sculpt_vdw_weight14", 166, [166]);
Clazz.defineEnumConstant(c$, "sculpt_bond_weight", 167, [167]);
Clazz.defineEnumConstant(c$, "sculpt_angl_weight", 168, [168]);
Clazz.defineEnumConstant(c$, "sculpt_pyra_weight", 169, [169]);
Clazz.defineEnumConstant(c$, "sculpt_plan_weight", 170, [170]);
Clazz.defineEnumConstant(c$, "sculpting_cycles", 171, [171]);
Clazz.defineEnumConstant(c$, "sphere_transparency", 172, [172]);
Clazz.defineEnumConstant(c$, "sphere_color", 173, [173]);
Clazz.defineEnumConstant(c$, "sculpt_field_mask", 174, [174]);
Clazz.defineEnumConstant(c$, "sculpt_hb_overlap", 175, [175]);
Clazz.defineEnumConstant(c$, "sculpt_hb_overlap_base", 176, [176]);
Clazz.defineEnumConstant(c$, "legacy_vdw_radii", 177, [177]);
Clazz.defineEnumConstant(c$, "sculpt_memory", 178, [178]);
Clazz.defineEnumConstant(c$, "connect_mode", 179, [179]);
Clazz.defineEnumConstant(c$, "cartoon_cylindrical_helices", 180, [180]);
Clazz.defineEnumConstant(c$, "cartoon_helix_radius", 181, [181]);
Clazz.defineEnumConstant(c$, "connect_cutoff", 182, [182]);
Clazz.defineEnumConstant(c$, "save_pdb_ss", 183, [183]);
Clazz.defineEnumConstant(c$, "sculpt_line_weight", 184, [184]);
Clazz.defineEnumConstant(c$, "fit_iterations", 185, [185]);
Clazz.defineEnumConstant(c$, "fit_tolerance", 186, [186]);
Clazz.defineEnumConstant(c$, "batch_prefix", 187, [187]);
Clazz.defineEnumConstant(c$, "stereo_mode", 188, [188]);
Clazz.defineEnumConstant(c$, "cgo_sphere_quality", 189, [189]);
Clazz.defineEnumConstant(c$, "pdb_literal_names", 190, [190]);
Clazz.defineEnumConstant(c$, "wrap_output", 191, [191]);
Clazz.defineEnumConstant(c$, "fog_start", 192, [192]);
Clazz.defineEnumConstant(c$, "state", 193, [193]);
Clazz.defineEnumConstant(c$, "frame", 194, [194]);
Clazz.defineEnumConstant(c$, "ray_shadows", 195, [195]);
Clazz.defineEnumConstant(c$, "ribbon_trace_atoms", 196, [196]);
Clazz.defineEnumConstant(c$, "security", 197, [197]);
Clazz.defineEnumConstant(c$, "stick_transparency", 198, [198]);
Clazz.defineEnumConstant(c$, "ray_transparency_shadows", 199, [199]);
Clazz.defineEnumConstant(c$, "session_version_check", 200, [200]);
Clazz.defineEnumConstant(c$, "ray_transparency_specular", 201, [201]);
Clazz.defineEnumConstant(c$, "stereo_double_pump_mono", 202, [202]);
Clazz.defineEnumConstant(c$, "sphere_solvent", 203, [203]);
Clazz.defineEnumConstant(c$, "mesh_quality", 204, [204]);
Clazz.defineEnumConstant(c$, "mesh_solvent", 205, [205]);
Clazz.defineEnumConstant(c$, "dot_solvent", 206, [206]);
Clazz.defineEnumConstant(c$, "ray_shadow_fudge", 207, [207]);
Clazz.defineEnumConstant(c$, "ray_triangle_fudge", 208, [208]);
Clazz.defineEnumConstant(c$, "debug_pick", 209, [209]);
Clazz.defineEnumConstant(c$, "dot_color", 210, [210]);
Clazz.defineEnumConstant(c$, "mouse_limit", 211, [211]);
Clazz.defineEnumConstant(c$, "mouse_scale", 212, [212]);
Clazz.defineEnumConstant(c$, "transparency_mode", 213, [213]);
Clazz.defineEnumConstant(c$, "clamp_colors", 214, [214]);
Clazz.defineEnumConstant(c$, "pymol_space_max_red", 215, [215]);
Clazz.defineEnumConstant(c$, "pymol_space_max_green", 216, [216]);
Clazz.defineEnumConstant(c$, "pymol_space_max_blue", 217, [217]);
Clazz.defineEnumConstant(c$, "pymol_space_min_factor", 218, [218]);
Clazz.defineEnumConstant(c$, "roving_origin", 219, [219]);
Clazz.defineEnumConstant(c$, "roving_lines", 220, [220]);
Clazz.defineEnumConstant(c$, "roving_sticks", 221, [221]);
Clazz.defineEnumConstant(c$, "roving_spheres", 222, [222]);
Clazz.defineEnumConstant(c$, "roving_labels", 223, [223]);
Clazz.defineEnumConstant(c$, "roving_delay", 224, [224]);
Clazz.defineEnumConstant(c$, "roving_selection", 225, [225]);
Clazz.defineEnumConstant(c$, "roving_byres", 226, [226]);
Clazz.defineEnumConstant(c$, "roving_ribbon", 227, [227]);
Clazz.defineEnumConstant(c$, "roving_cartoon", 228, [228]);
Clazz.defineEnumConstant(c$, "roving_polar_contacts", 229, [229]);
Clazz.defineEnumConstant(c$, "roving_polar_cutoff", 230, [230]);
Clazz.defineEnumConstant(c$, "roving_nonbonded", 231, [231]);
Clazz.defineEnumConstant(c$, "float_labels", 232, [232]);
Clazz.defineEnumConstant(c$, "roving_detail", 233, [233]);
Clazz.defineEnumConstant(c$, "roving_nb_spheres", 234, [234]);
Clazz.defineEnumConstant(c$, "ribbon_color", 235, [235]);
Clazz.defineEnumConstant(c$, "cartoon_color", 236, [236]);
Clazz.defineEnumConstant(c$, "ribbon_smooth", 237, [237]);
Clazz.defineEnumConstant(c$, "auto_color", 238, [238]);
Clazz.defineEnumConstant(c$, "auto_color_next", 239, [239]);
Clazz.defineEnumConstant(c$, "ray_interior_color", 240, [240]);
Clazz.defineEnumConstant(c$, "cartoon_highlight_color", 241, [241]);
Clazz.defineEnumConstant(c$, "coulomb_units_factor", 242, [242]);
Clazz.defineEnumConstant(c$, "coulomb_dielectric", 243, [243]);
Clazz.defineEnumConstant(c$, "ray_interior_shadows", 244, [244]);
Clazz.defineEnumConstant(c$, "ray_interior_texture", 245, [245]);
Clazz.defineEnumConstant(c$, "roving_map1_name", 246, [246]);
Clazz.defineEnumConstant(c$, "roving_map2_name", 247, [247]);
Clazz.defineEnumConstant(c$, "roving_map3_name", 248, [248]);
Clazz.defineEnumConstant(c$, "roving_map1_level", 249, [249]);
Clazz.defineEnumConstant(c$, "roving_map2_level", 250, [250]);
Clazz.defineEnumConstant(c$, "roving_map3_level", 251, [251]);
Clazz.defineEnumConstant(c$, "roving_isomesh", 252, [252]);
Clazz.defineEnumConstant(c$, "roving_isosurface", 253, [253]);
Clazz.defineEnumConstant(c$, "scenes_changed", 254, [254]);
Clazz.defineEnumConstant(c$, "gaussian_b_adjust", 255, [255]);
Clazz.defineEnumConstant(c$, "pdb_standard_order", 256, [256]);
Clazz.defineEnumConstant(c$, "cartoon_smooth_first", 257, [257]);
Clazz.defineEnumConstant(c$, "cartoon_smooth_last", 258, [258]);
Clazz.defineEnumConstant(c$, "cartoon_smooth_cycles", 259, [259]);
Clazz.defineEnumConstant(c$, "cartoon_flat_cycles", 260, [260]);
Clazz.defineEnumConstant(c$, "max_threads", 261, [261]);
Clazz.defineEnumConstant(c$, "show_progress", 262, [262]);
Clazz.defineEnumConstant(c$, "use_display_lists", 263, [263]);
Clazz.defineEnumConstant(c$, "cache_memory", 264, [264]);
Clazz.defineEnumConstant(c$, "simplify_display_lists", 265, [265]);
Clazz.defineEnumConstant(c$, "retain_order", 266, [266]);
Clazz.defineEnumConstant(c$, "pdb_hetatm_sort", 267, [267]);
Clazz.defineEnumConstant(c$, "pdb_use_ter_records", 268, [268]);
Clazz.defineEnumConstant(c$, "cartoon_trace_atoms", 269, [269]);
Clazz.defineEnumConstant(c$, "ray_oversample_cutoff", 270, [270]);
Clazz.defineEnumConstant(c$, "gaussian_resolution", 271, [271]);
Clazz.defineEnumConstant(c$, "gaussian_b_floor", 272, [272]);
Clazz.defineEnumConstant(c$, "sculpt_nb_interval", 273, [273]);
Clazz.defineEnumConstant(c$, "sculpt_tors_weight", 274, [274]);
Clazz.defineEnumConstant(c$, "sculpt_tors_tolerance", 275, [275]);
Clazz.defineEnumConstant(c$, "stick_ball", 276, [276]);
Clazz.defineEnumConstant(c$, "stick_ball_ratio", 277, [277]);
Clazz.defineEnumConstant(c$, "stick_fixed_radius", 278, [278]);
Clazz.defineEnumConstant(c$, "cartoon_transparency", 279, [279]);
Clazz.defineEnumConstant(c$, "dash_round_ends", 280, [280]);
Clazz.defineEnumConstant(c$, "h_bond_max_angle", 281, [281]);
Clazz.defineEnumConstant(c$, "h_bond_cutoff_center", 282, [282]);
Clazz.defineEnumConstant(c$, "h_bond_cutoff_edge", 283, [283]);
Clazz.defineEnumConstant(c$, "h_bond_power_a", 284, [284]);
Clazz.defineEnumConstant(c$, "h_bond_power_b", 285, [285]);
Clazz.defineEnumConstant(c$, "h_bond_cone", 286, [286]);
Clazz.defineEnumConstant(c$, "ss_helix_psi_target", 287, [287]);
Clazz.defineEnumConstant(c$, "ss_helix_psi_include", 288, [288]);
Clazz.defineEnumConstant(c$, "ss_helix_psi_exclude", 289, [289]);
Clazz.defineEnumConstant(c$, "ss_helix_phi_target", 290, [290]);
Clazz.defineEnumConstant(c$, "ss_helix_phi_include", 291, [291]);
Clazz.defineEnumConstant(c$, "ss_helix_phi_exclude", 292, [292]);
Clazz.defineEnumConstant(c$, "ss_strand_psi_target", 293, [293]);
Clazz.defineEnumConstant(c$, "ss_strand_psi_include", 294, [294]);
Clazz.defineEnumConstant(c$, "ss_strand_psi_exclude", 295, [295]);
Clazz.defineEnumConstant(c$, "ss_strand_phi_target", 296, [296]);
Clazz.defineEnumConstant(c$, "ss_strand_phi_include", 297, [297]);
Clazz.defineEnumConstant(c$, "ss_strand_phi_exclude", 298, [298]);
Clazz.defineEnumConstant(c$, "movie_loop", 299, [299]);
Clazz.defineEnumConstant(c$, "pdb_retain_ids", 300, [300]);
Clazz.defineEnumConstant(c$, "pdb_no_end_record", 301, [301]);
Clazz.defineEnumConstant(c$, "cgo_dot_width", 302, [302]);
Clazz.defineEnumConstant(c$, "cgo_dot_radius", 303, [303]);
Clazz.defineEnumConstant(c$, "defer_updates", 304, [304]);
Clazz.defineEnumConstant(c$, "normalize_o_maps", 305, [305]);
Clazz.defineEnumConstant(c$, "swap_dsn6_bytes", 306, [306]);
Clazz.defineEnumConstant(c$, "pdb_insertions_go_first", 307, [307]);
Clazz.defineEnumConstant(c$, "roving_origin_z", 308, [308]);
Clazz.defineEnumConstant(c$, "roving_origin_z_cushion", 309, [309]);
Clazz.defineEnumConstant(c$, "specular_intensity", 310, [310]);
Clazz.defineEnumConstant(c$, "overlay_lines", 311, [311]);
Clazz.defineEnumConstant(c$, "ray_transparency_spec_cut", 312, [312]);
Clazz.defineEnumConstant(c$, "internal_prompt", 313, [313]);
Clazz.defineEnumConstant(c$, "normalize_grd_maps", 314, [314]);
Clazz.defineEnumConstant(c$, "ray_blend_colors", 315, [315]);
Clazz.defineEnumConstant(c$, "ray_blend_red", 316, [316]);
Clazz.defineEnumConstant(c$, "ray_blend_green", 317, [317]);
Clazz.defineEnumConstant(c$, "ray_blend_blue", 318, [318]);
Clazz.defineEnumConstant(c$, "png_screen_gamma", 319, [319]);
Clazz.defineEnumConstant(c$, "png_file_gamma", 320, [320]);
Clazz.defineEnumConstant(c$, "editor_label_fragments", 321, [321]);
Clazz.defineEnumConstant(c$, "internal_gui_control_size", 322, [322]);
Clazz.defineEnumConstant(c$, "auto_dss", 323, [323]);
Clazz.defineEnumConstant(c$, "transparency_picking_mode", 324, [324]);
Clazz.defineEnumConstant(c$, "virtual_trackball", 325, [325]);
Clazz.defineEnumConstant(c$, "pdb_reformat_names_mode", 326, [326]);
Clazz.defineEnumConstant(c$, "ray_pixel_scale", 327, [327]);
Clazz.defineEnumConstant(c$, "label_font_id", 328, [328]);
Clazz.defineEnumConstant(c$, "pdb_conect_all", 329, [329]);
Clazz.defineEnumConstant(c$, "button_mode_name", 330, [330]);
Clazz.defineEnumConstant(c$, "surface_type", 331, [331]);
Clazz.defineEnumConstant(c$, "dot_normals", 332, [332]);
Clazz.defineEnumConstant(c$, "session_migration", 333, [333]);
Clazz.defineEnumConstant(c$, "mesh_normals", 334, [334]);
Clazz.defineEnumConstant(c$, "mesh_type", 335, [335]);
Clazz.defineEnumConstant(c$, "dot_lighting", 336, [336]);
Clazz.defineEnumConstant(c$, "mesh_lighting", 337, [337]);
Clazz.defineEnumConstant(c$, "surface_solvent", 338, [338]);
Clazz.defineEnumConstant(c$, "triangle_max_passes", 339, [339]);
Clazz.defineEnumConstant(c$, "ray_interior_reflect", 340, [340]);
Clazz.defineEnumConstant(c$, "internal_gui_mode", 341, [341]);
Clazz.defineEnumConstant(c$, "surface_carve_selection", 342, [342]);
Clazz.defineEnumConstant(c$, "surface_carve_state", 343, [343]);
Clazz.defineEnumConstant(c$, "surface_carve_cutoff", 344, [344]);
Clazz.defineEnumConstant(c$, "surface_clear_selection", 345, [345]);
Clazz.defineEnumConstant(c$, "surface_clear_state", 346, [346]);
Clazz.defineEnumConstant(c$, "surface_clear_cutoff", 347, [347]);
Clazz.defineEnumConstant(c$, "surface_trim_cutoff", 348, [348]);
Clazz.defineEnumConstant(c$, "surface_trim_factor", 349, [349]);
Clazz.defineEnumConstant(c$, "ray_max_passes", 350, [350]);
Clazz.defineEnumConstant(c$, "active_selections", 351, [351]);
Clazz.defineEnumConstant(c$, "ray_transparency_contrast", 352, [352]);
Clazz.defineEnumConstant(c$, "seq_view", 353, [353]);
Clazz.defineEnumConstant(c$, "mouse_selection_mode", 354, [354]);
Clazz.defineEnumConstant(c$, "seq_view_label_spacing", 355, [355]);
Clazz.defineEnumConstant(c$, "seq_view_label_start", 356, [356]);
Clazz.defineEnumConstant(c$, "seq_view_format", 357, [357]);
Clazz.defineEnumConstant(c$, "seq_view_location", 358, [358]);
Clazz.defineEnumConstant(c$, "seq_view_overlay", 359, [359]);
Clazz.defineEnumConstant(c$, "auto_classify_atoms", 360, [360]);
Clazz.defineEnumConstant(c$, "cartoon_nucleic_acid_mode", 361, [361]);
Clazz.defineEnumConstant(c$, "seq_view_color", 362, [362]);
Clazz.defineEnumConstant(c$, "seq_view_label_mode", 363, [363]);
Clazz.defineEnumConstant(c$, "surface_ramp_above_mode", 364, [364]);
Clazz.defineEnumConstant(c$, "stereo", 365, [365]);
Clazz.defineEnumConstant(c$, "wizard_prompt_mode", 366, [366]);
Clazz.defineEnumConstant(c$, "coulomb_cutoff", 367, [367]);
Clazz.defineEnumConstant(c$, "slice_track_camera", 368, [368]);
Clazz.defineEnumConstant(c$, "slice_height_scale", 369, [369]);
Clazz.defineEnumConstant(c$, "slice_height_map", 370, [370]);
Clazz.defineEnumConstant(c$, "slice_grid", 371, [371]);
Clazz.defineEnumConstant(c$, "slice_dynamic_grid", 372, [372]);
Clazz.defineEnumConstant(c$, "slice_dynamic_grid_resolution", 373, [373]);
Clazz.defineEnumConstant(c$, "pdb_insure_orthogonal", 374, [374]);
Clazz.defineEnumConstant(c$, "ray_direct_shade", 375, [375]);
Clazz.defineEnumConstant(c$, "stick_color", 376, [376]);
Clazz.defineEnumConstant(c$, "cartoon_putty_radius", 377, [377]);
Clazz.defineEnumConstant(c$, "cartoon_putty_quality", 378, [378]);
Clazz.defineEnumConstant(c$, "cartoon_putty_scale_min", 379, [379]);
Clazz.defineEnumConstant(c$, "cartoon_putty_scale_max", 380, [380]);
Clazz.defineEnumConstant(c$, "cartoon_putty_scale_power", 381, [381]);
Clazz.defineEnumConstant(c$, "cartoon_putty_range", 382, [382]);
Clazz.defineEnumConstant(c$, "cartoon_side_chain_helper", 383, [383]);
Clazz.defineEnumConstant(c$, "surface_optimize_subsets", 384, [384]);
Clazz.defineEnumConstant(c$, "multiplex", 385, [385]);
Clazz.defineEnumConstant(c$, "texture_fonts", 386, [386]);
Clazz.defineEnumConstant(c$, "pqr_workarounds", 387, [387]);
Clazz.defineEnumConstant(c$, "animation", 388, [388]);
Clazz.defineEnumConstant(c$, "animation_duration", 389, [389]);
Clazz.defineEnumConstant(c$, "scene_animation", 390, [390]);
Clazz.defineEnumConstant(c$, "line_stick_helper", 391, [391]);
Clazz.defineEnumConstant(c$, "ray_orthoscopic", 392, [392]);
Clazz.defineEnumConstant(c$, "ribbon_side_chain_helper", 393, [393]);
Clazz.defineEnumConstant(c$, "selection_width_max", 394, [394]);
Clazz.defineEnumConstant(c$, "selection_width_scale", 395, [395]);
Clazz.defineEnumConstant(c$, "scene_current_name", 396, [396]);
Clazz.defineEnumConstant(c$, "presentation", 397, [397]);
Clazz.defineEnumConstant(c$, "presentation_mode", 398, [398]);
Clazz.defineEnumConstant(c$, "pdb_truncate_residue_name", 399, [399]);
Clazz.defineEnumConstant(c$, "scene_loop", 400, [400]);
Clazz.defineEnumConstant(c$, "sweep_mode", 401, [401]);
Clazz.defineEnumConstant(c$, "sweep_phase", 402, [402]);
Clazz.defineEnumConstant(c$, "scene_restart_movie_delay", 403, [403]);
Clazz.defineEnumConstant(c$, "mouse_restart_movie_delay", 404, [404]);
Clazz.defineEnumConstant(c$, "angle_size", 405, [405]);
Clazz.defineEnumConstant(c$, "angle_label_position", 406, [406]);
Clazz.defineEnumConstant(c$, "dihedral_size", 407, [407]);
Clazz.defineEnumConstant(c$, "dihedral_label_position", 408, [408]);
Clazz.defineEnumConstant(c$, "defer_builds_mode", 409, [409]);
Clazz.defineEnumConstant(c$, "seq_view_discrete_by_state", 410, [410]);
Clazz.defineEnumConstant(c$, "scene_animation_duration", 411, [411]);
Clazz.defineEnumConstant(c$, "wildcard", 412, [412]);
Clazz.defineEnumConstant(c$, "atom_name_wildcard", 413, [413]);
Clazz.defineEnumConstant(c$, "ignore_case", 414, [414]);
Clazz.defineEnumConstant(c$, "presentation_auto_quit", 415, [415]);
Clazz.defineEnumConstant(c$, "editor_auto_dihedral", 416, [416]);
Clazz.defineEnumConstant(c$, "presentation_auto_start", 417, [417]);
Clazz.defineEnumConstant(c$, "validate_object_names", 418, [418]);
Clazz.defineEnumConstant(c$, "unused_boolean_def_true", 419, [419]);
Clazz.defineEnumConstant(c$, "auto_show_spheres", 420, [420]);
Clazz.defineEnumConstant(c$, "sphere_mode", 421, [421]);
Clazz.defineEnumConstant(c$, "sphere_point_max_size", 422, [422]);
Clazz.defineEnumConstant(c$, "sphere_point_size", 423, [423]);
Clazz.defineEnumConstant(c$, "pdb_honor_model_number", 424, [424]);
Clazz.defineEnumConstant(c$, "rank_assisted_sorts", 425, [425]);
Clazz.defineEnumConstant(c$, "ribbon_nucleic_acid_mode", 426, [426]);
Clazz.defineEnumConstant(c$, "cartoon_ring_mode", 427, [427]);
Clazz.defineEnumConstant(c$, "cartoon_ring_width", 428, [428]);
Clazz.defineEnumConstant(c$, "cartoon_ring_color", 429, [429]);
Clazz.defineEnumConstant(c$, "cartoon_ring_finder", 430, [430]);
Clazz.defineEnumConstant(c$, "cartoon_tube_cap", 431, [431]);
Clazz.defineEnumConstant(c$, "cartoon_loop_cap", 432, [432]);
Clazz.defineEnumConstant(c$, "nvidia_bugs", 433, [433]);
Clazz.defineEnumConstant(c$, "image_dots_per_inch", 434, [434]);
Clazz.defineEnumConstant(c$, "opaque_background", 435, [435]);
Clazz.defineEnumConstant(c$, "draw_frames", 436, [436]);
Clazz.defineEnumConstant(c$, "show_alpha_checker", 437, [437]);
Clazz.defineEnumConstant(c$, "matrix_mode", 438, [438]);
Clazz.defineEnumConstant(c$, "editor_auto_origin", 439, [439]);
Clazz.defineEnumConstant(c$, "session_file", 440, [440]);
Clazz.defineEnumConstant(c$, "cgo_transparency", 441, [441]);
Clazz.defineEnumConstant(c$, "legacy_mouse_zoom", 442, [442]);
Clazz.defineEnumConstant(c$, "auto_number_selections", 443, [443]);
Clazz.defineEnumConstant(c$, "sculpt_vdw_vis_mode", 444, [444]);
Clazz.defineEnumConstant(c$, "sculpt_vdw_vis_min", 445, [445]);
Clazz.defineEnumConstant(c$, "sculpt_vdw_vis_mid", 446, [446]);
Clazz.defineEnumConstant(c$, "sculpt_vdw_vis_max", 447, [447]);
Clazz.defineEnumConstant(c$, "cartoon_ladder_mode", 448, [448]);
Clazz.defineEnumConstant(c$, "cartoon_ladder_radius", 449, [449]);
Clazz.defineEnumConstant(c$, "cartoon_ladder_color", 450, [450]);
Clazz.defineEnumConstant(c$, "cartoon_nucleic_acid_color", 451, [451]);
Clazz.defineEnumConstant(c$, "cartoon_ring_transparency", 452, [452]);
Clazz.defineEnumConstant(c$, "label_size", 453, [453]);
Clazz.defineEnumConstant(c$, "spec_direct", 454, [454]);
Clazz.defineEnumConstant(c$, "light_count", 455, [455]);
Clazz.defineEnumConstant(c$, "light2", 456, [456]);
Clazz.defineEnumConstant(c$, "light3", 457, [457]);
Clazz.defineEnumConstant(c$, "hide_underscore_names", 458, [458]);
Clazz.defineEnumConstant(c$, "selection_round_points", 459, [459]);
Clazz.defineEnumConstant(c$, "distance_exclusion", 460, [460]);
Clazz.defineEnumConstant(c$, "h_bond_exclusion", 461, [461]);
Clazz.defineEnumConstant(c$, "label_shadow_mode", 462, [462]);
Clazz.defineEnumConstant(c$, "light4", 463, [463]);
Clazz.defineEnumConstant(c$, "light5", 464, [464]);
Clazz.defineEnumConstant(c$, "light6", 465, [465]);
Clazz.defineEnumConstant(c$, "light7", 466, [466]);
Clazz.defineEnumConstant(c$, "label_outline_color", 467, [467]);
Clazz.defineEnumConstant(c$, "ray_trace_mode", 468, [468]);
Clazz.defineEnumConstant(c$, "ray_trace_gain", 469, [469]);
Clazz.defineEnumConstant(c$, "selection_visible_only", 470, [470]);
Clazz.defineEnumConstant(c$, "label_position", 471, [471]);
Clazz.defineEnumConstant(c$, "ray_trace_depth_factor", 472, [472]);
Clazz.defineEnumConstant(c$, "ray_trace_slope_factor", 473, [473]);
Clazz.defineEnumConstant(c$, "ray_trace_disco_factor", 474, [474]);
Clazz.defineEnumConstant(c$, "ray_shadow_decay_factor", 475, [475]);
Clazz.defineEnumConstant(c$, "ray_interior_mode", 476, [476]);
Clazz.defineEnumConstant(c$, "ray_legacy_lighting", 477, [477]);
Clazz.defineEnumConstant(c$, "sculpt_auto_center", 478, [478]);
Clazz.defineEnumConstant(c$, "pdb_discrete_chains", 479, [479]);
Clazz.defineEnumConstant(c$, "pdb_unbond_cations", 480, [480]);
Clazz.defineEnumConstant(c$, "sculpt_tri_scale", 481, [481]);
Clazz.defineEnumConstant(c$, "sculpt_tri_weight", 482, [482]);
Clazz.defineEnumConstant(c$, "sculpt_tri_min", 483, [483]);
Clazz.defineEnumConstant(c$, "sculpt_tri_max", 484, [484]);
Clazz.defineEnumConstant(c$, "sculpt_tri_mode", 485, [485]);
Clazz.defineEnumConstant(c$, "pdb_echo_tags", 486, [486]);
Clazz.defineEnumConstant(c$, "connect_bonded", 487, [487]);
Clazz.defineEnumConstant(c$, "spec_direct_power", 488, [488]);
Clazz.defineEnumConstant(c$, "light8", 489, [489]);
Clazz.defineEnumConstant(c$, "light9", 490, [490]);
Clazz.defineEnumConstant(c$, "ray_shadow_decay_range", 491, [491]);
Clazz.defineEnumConstant(c$, "spec_count", 492, [492]);
Clazz.defineEnumConstant(c$, "sculpt_min_scale", 493, [493]);
Clazz.defineEnumConstant(c$, "sculpt_min_weight", 494, [494]);
Clazz.defineEnumConstant(c$, "sculpt_min_min", 495, [495]);
Clazz.defineEnumConstant(c$, "sculpt_min_max", 496, [496]);
Clazz.defineEnumConstant(c$, "sculpt_max_scale", 497, [497]);
Clazz.defineEnumConstant(c$, "sculpt_max_weight", 498, [498]);
Clazz.defineEnumConstant(c$, "sculpt_max_min", 499, [499]);
Clazz.defineEnumConstant(c$, "sculpt_max_max", 500, [500]);
Clazz.defineEnumConstant(c$, "surface_circumscribe", 501, [501]);
Clazz.defineEnumConstant(c$, "sculpt_avd_weight", 502, [502]);
Clazz.defineEnumConstant(c$, "sculpt_avd_gap", 503, [503]);
Clazz.defineEnumConstant(c$, "sculpt_avd_range", 504, [504]);
Clazz.defineEnumConstant(c$, "sculpt_avd_excl", 505, [505]);
Clazz.defineEnumConstant(c$, "async_builds", 506, [506]);
Clazz.defineEnumConstant(c$, "fetch_path", 507, [507]);
Clazz.defineEnumConstant(c$, "cartoon_ring_radius", 508, [508]);
Clazz.defineEnumConstant(c$, "ray_color_ramps", 509, [509]);
Clazz.defineEnumConstant(c$, "ray_hint_camera", 510, [510]);
Clazz.defineEnumConstant(c$, "ray_hint_shadow", 511, [511]);
Clazz.defineEnumConstant(c$, "stick_valence_scale", 512, [512]);
Clazz.defineEnumConstant(c$, "seq_view_alignment", 513, [513]);
Clazz.defineEnumConstant(c$, "seq_view_unaligned_mode", 514, [514]);
Clazz.defineEnumConstant(c$, "seq_view_unaligned_color", 515, [515]);
Clazz.defineEnumConstant(c$, "seq_view_fill_char", 516, [516]);
Clazz.defineEnumConstant(c$, "seq_view_fill_color", 517, [517]);
Clazz.defineEnumConstant(c$, "seq_view_label_color", 518, [518]);
Clazz.defineEnumConstant(c$, "surface_carve_normal_cutoff", 519, [519]);
Clazz.defineEnumConstant(c$, "trace_atoms_mode", 520, [520]);
Clazz.defineEnumConstant(c$, "session_changed", 521, [521]);
Clazz.defineEnumConstant(c$, "ray_clip_shadows", 522, [522]);
Clazz.defineEnumConstant(c$, "mouse_wheel_scale", 523, [523]);
Clazz.defineEnumConstant(c$, "nonbonded_transparency", 524, [524]);
Clazz.defineEnumConstant(c$, "ray_spec_local", 525, [525]);
Clazz.defineEnumConstant(c$, "line_color", 526, [526]);
Clazz.defineEnumConstant(c$, "ray_label_specular", 527, [527]);
Clazz.defineEnumConstant(c$, "mesh_skip", 528, [528]);
Clazz.defineEnumConstant(c$, "label_digits", 529, [529]);
Clazz.defineEnumConstant(c$, "label_distance_digits", 530, [530]);
Clazz.defineEnumConstant(c$, "label_angle_digits", 531, [531]);
Clazz.defineEnumConstant(c$, "label_dihedral_digits", 532, [532]);
Clazz.defineEnumConstant(c$, "surface_negative_visible", 533, [533]);
Clazz.defineEnumConstant(c$, "surface_negative_color", 534, [534]);
Clazz.defineEnumConstant(c$, "mesh_negative_visible", 535, [535]);
Clazz.defineEnumConstant(c$, "mesh_negative_color", 536, [536]);
Clazz.defineEnumConstant(c$, "group_auto_mode", 537, [537]);
Clazz.defineEnumConstant(c$, "group_full_member_names", 538, [538]);
Clazz.defineEnumConstant(c$, "gradient_max_length", 539, [539]);
Clazz.defineEnumConstant(c$, "gradient_min_length", 540, [540]);
Clazz.defineEnumConstant(c$, "gradient_min_slope", 541, [541]);
Clazz.defineEnumConstant(c$, "gradient_normal_min_dot", 542, [542]);
Clazz.defineEnumConstant(c$, "gradient_step_size", 543, [543]);
Clazz.defineEnumConstant(c$, "gradient_spacing", 544, [544]);
Clazz.defineEnumConstant(c$, "gradient_symmetry", 545, [545]);
Clazz.defineEnumConstant(c$, "ray_trace_color", 546, [546]);
Clazz.defineEnumConstant(c$, "group_arrow_prefix", 547, [547]);
Clazz.defineEnumConstant(c$, "suppress_hidden", 548, [548]);
Clazz.defineEnumConstant(c$, "session_compression", 549, [549]);
Clazz.defineEnumConstant(c$, "movie_fps", 550, [550]);
Clazz.defineEnumConstant(c$, "ray_transparency_oblique", 551, [551]);
Clazz.defineEnumConstant(c$, "ray_trace_trans_cutoff", 552, [552]);
Clazz.defineEnumConstant(c$, "ray_trace_persist_cutoff", 553, [553]);
Clazz.defineEnumConstant(c$, "ray_transparency_oblique_power", 554, [554]);
Clazz.defineEnumConstant(c$, "ray_scatter", 555, [555]);
Clazz.defineEnumConstant(c$, "h_bond_from_proton", 556, [556]);
Clazz.defineEnumConstant(c$, "auto_copy_images", 557, [557]);
Clazz.defineEnumConstant(c$, "moe_separate_chains", 558, [558]);
Clazz.defineEnumConstant(c$, "transparency_global_sort", 559, [559]);
Clazz.defineEnumConstant(c$, "hide_long_bonds", 560, [560]);
Clazz.defineEnumConstant(c$, "auto_rename_duplicate_objects", 561, [561]);
Clazz.defineEnumConstant(c$, "pdb_hetatm_guess_valences", 562, [562]);
Clazz.defineEnumConstant(c$, "ellipsoid_quality", 563, [563]);
Clazz.defineEnumConstant(c$, "cgo_ellipsoid_quality", 564, [564]);
Clazz.defineEnumConstant(c$, "movie_animate_by_frame", 565, [565]);
Clazz.defineEnumConstant(c$, "ramp_blend_nearby_colors", 566, [566]);
Clazz.defineEnumConstant(c$, "auto_defer_builds", 567, [567]);
Clazz.defineEnumConstant(c$, "ellipsoid_probability", 568, [568]);
Clazz.defineEnumConstant(c$, "ellipsoid_scale", 569, [569]);
Clazz.defineEnumConstant(c$, "ellipsoid_color", 570, [570]);
Clazz.defineEnumConstant(c$, "ellipsoid_transparency", 571, [571]);
Clazz.defineEnumConstant(c$, "movie_rock", 572, [572]);
Clazz.defineEnumConstant(c$, "cache_mode", 573, [573]);
Clazz.defineEnumConstant(c$, "dash_color", 574, [574]);
Clazz.defineEnumConstant(c$, "angle_color", 575, [575]);
Clazz.defineEnumConstant(c$, "dihedral_color", 576, [576]);
Clazz.defineEnumConstant(c$, "grid_mode", 577, [577]);
Clazz.defineEnumConstant(c$, "cache_max", 578, [578]);
Clazz.defineEnumConstant(c$, "grid_slot", 579, [579]);
Clazz.defineEnumConstant(c$, "grid_max", 580, [580]);
Clazz.defineEnumConstant(c$, "cartoon_putty_transform", 581, [581]);
Clazz.defineEnumConstant(c$, "rock", 582, [582]);
Clazz.defineEnumConstant(c$, "cone_quality", 583, [583]);
Clazz.defineEnumConstant(c$, "pdb_formal_charges", 584, [584]);
Clazz.defineEnumConstant(c$, "ati_bugs", 585, [585]);
Clazz.defineEnumConstant(c$, "geometry_export_mode", 586, [586]);
Clazz.defineEnumConstant(c$, "mouse_grid", 587, [587]);
Clazz.defineEnumConstant(c$, "mesh_cutoff", 588, [588]);
Clazz.defineEnumConstant(c$, "mesh_carve_selection", 589, [589]);
Clazz.defineEnumConstant(c$, "mesh_carve_state", 590, [590]);
Clazz.defineEnumConstant(c$, "mesh_carve_cutoff", 591, [591]);
Clazz.defineEnumConstant(c$, "mesh_clear_selection", 592, [592]);
Clazz.defineEnumConstant(c$, "mesh_clear_state", 593, [593]);
Clazz.defineEnumConstant(c$, "mesh_clear_cutoff", 594, [594]);
Clazz.defineEnumConstant(c$, "mesh_grid_max", 595, [595]);
Clazz.defineEnumConstant(c$, "session_cache_optimize", 596, [596]);
Clazz.defineEnumConstant(c$, "sdof_drag_scale", 597, [597]);
Clazz.defineEnumConstant(c$, "scene_buttons_mode", 598, [598]);
Clazz.defineEnumConstant(c$, "scene_buttons", 599, [599]);
Clazz.defineEnumConstant(c$, "map_auto_expand_sym", 600, [600]);
Clazz.defineEnumConstant(c$, "image_copy_always", 601, [601]);
Clazz.defineEnumConstant(c$, "max_ups", 602, [602]);
Clazz.defineEnumConstant(c$, "auto_overlay", 603, [603]);
Clazz.defineEnumConstant(c$, "stick_ball_color", 604, [604]);
Clazz.defineEnumConstant(c$, "stick_h_scale", 605, [605]);
Clazz.defineEnumConstant(c$, "sculpt_pyra_inv_weight", 606, [606]);
Clazz.defineEnumConstant(c$, "keep_alive", 607, [607]);
Clazz.defineEnumConstant(c$, "fit_kabsch", 608, [608]);
Clazz.defineEnumConstant(c$, "stereo_dynamic_strength", 609, [609]);
Clazz.defineEnumConstant(c$, "dynamic_width", 610, [610]);
Clazz.defineEnumConstant(c$, "dynamic_width_factor", 611, [611]);
Clazz.defineEnumConstant(c$, "dynamic_width_min", 612, [612]);
Clazz.defineEnumConstant(c$, "dynamic_width_max", 613, [613]);
Clazz.defineEnumConstant(c$, "draw_mode", 614, [614]);
Clazz.defineEnumConstant(c$, "clean_electro_mode", 615, [615]);
Clazz.defineEnumConstant(c$, "valence_mode", 616, [616]);
Clazz.defineEnumConstant(c$, "show_frame_rate", 617, [617]);
Clazz.defineEnumConstant(c$, "movie_panel", 618, [618]);
Clazz.defineEnumConstant(c$, "mouse_z_scale", 619, [619]);
Clazz.defineEnumConstant(c$, "movie_auto_store", 620, [620]);
Clazz.defineEnumConstant(c$, "movie_auto_interpolate", 621, [621]);
Clazz.defineEnumConstant(c$, "movie_panel_row_height", 622, [622]);
Clazz.defineEnumConstant(c$, "scene_frame_mode", 623, [623]);
Clazz.defineEnumConstant(c$, "surface_cavity_mode", 624, [624]);
Clazz.defineEnumConstant(c$, "surface_cavity_radius", 625, [625]);
Clazz.defineEnumConstant(c$, "surface_cavity_cutoff", 626, [626]);
Clazz.defineEnumConstant(c$, "motion_power", 627, [627]);
Clazz.defineEnumConstant(c$, "motion_bias", 628, [628]);
Clazz.defineEnumConstant(c$, "motion_simple", 629, [629]);
Clazz.defineEnumConstant(c$, "motion_linear", 630, [630]);
Clazz.defineEnumConstant(c$, "motion_hand", 631, [631]);
Clazz.defineEnumConstant(c$, "pdb_ignore_conect", 632, [632]);
Clazz.defineEnumConstant(c$, "editor_bond_cycle_mode", 633, [633]);
Clazz.defineEnumConstant(c$, "movie_quality", 634, [634]);
Clazz.defineEnumConstant(c$, "label_anchor", 635, [635]);
Clazz.defineEnumConstant(c$, "fetch_host", 636, [636]);
Clazz.defineEnumConstant(c$, "dynamic_measures", 637, [637]);
Clazz.defineEnumConstant(c$, "neighbor_cutoff", 638, [638]);
Clazz.defineEnumConstant(c$, "heavy_neighbor_cutoff", 639, [639]);
Clazz.defineEnumConstant(c$, "polar_neighbor_cutoff", 640, [640]);
Clazz.defineEnumConstant(c$, "surface_residue_cutoff", 641, [641]);
Clazz.defineEnumConstant(c$, "surface_use_shader", 642, [642]);
Clazz.defineEnumConstant(c$, "cartoon_use_shader", 643, [643]);
Clazz.defineEnumConstant(c$, "stick_use_shader", 644, [644]);
Clazz.defineEnumConstant(c$, "line_use_shader", 645, [645]);
Clazz.defineEnumConstant(c$, "sphere_use_shader", 646, [646]);
Clazz.defineEnumConstant(c$, "use_shaders", 647, [647]);
Clazz.defineEnumConstant(c$, "shader_path", 648, [648]);
Clazz.defineEnumConstant(c$, "volume_bit_depth", 649, [649]);
Clazz.defineEnumConstant(c$, "volume_color", 650, [650]);
Clazz.defineEnumConstant(c$, "volume_layers", 651, [651]);
Clazz.defineEnumConstant(c$, "volume_data_range", 652, [652]);
Clazz.defineEnumConstant(c$, "auto_defer_atom_count", 653, [653]);
Clazz.defineEnumConstant(c$, "default_refmac_names", 654, [654]);
Clazz.defineEnumConstant(c$, "default_phenix_names", 655, [655]);
Clazz.defineEnumConstant(c$, "default_phenix_no_fill_names", 656, [656]);
Clazz.defineEnumConstant(c$, "default_buster_names", 657, [657]);
Clazz.defineEnumConstant(c$, "default_fofc_map_rep", 658, [658]);
Clazz.defineEnumConstant(c$, "default_2fofc_map_rep", 659, [659]);
Clazz.defineEnumConstant(c$, "atom_type_format", 660, [660]);
Clazz.defineEnumConstant(c$, "autoclose_dialogs", 661, [661]);
Clazz.defineEnumConstant(c$, "bg_gradient", 662, [662]);
Clazz.defineEnumConstant(c$, "bg_rgb_top", 663, [663]);
Clazz.defineEnumConstant(c$, "bg_rgb_bottom", 664, [664]);
Clazz.defineEnumConstant(c$, "ray_volume", 665, [665]);
Clazz.defineEnumConstant(c$, "ribbon_transparency", 666, [666]);
Clazz.defineEnumConstant(c$, "state_counter_mode", 667, [667]);
Clazz.defineEnumConstant(c$, "cgo_use_shader", 668, [668]);
Clazz.defineEnumConstant(c$, "cgo_shader_ub_color", 669, [669]);
Clazz.defineEnumConstant(c$, "cgo_shader_ub_normal", 670, [670]);
Clazz.defineEnumConstant(c$, "cgo_lighting", 671, [671]);
Clazz.defineEnumConstant(c$, "mesh_use_shader", 672, [672]);
Clazz.defineEnumConstant(c$, "stick_debug", 673, [673]);
Clazz.defineEnumConstant(c$, "cgo_debug", 674, [674]);
Clazz.defineEnumConstant(c$, "stick_round_nub", 675, [675]);
Clazz.defineEnumConstant(c$, "stick_good_geometry", 676, [676]);
Clazz.defineEnumConstant(c$, "stick_as_cylinders", 677, [677]);
Clazz.defineEnumConstant(c$, "mesh_as_cylinders", 678, [678]);
Clazz.defineEnumConstant(c$, "line_as_cylinders", 679, [679]);
Clazz.defineEnumConstant(c$, "ribbon_as_cylinders", 680, [680]);
Clazz.defineEnumConstant(c$, "ribbon_use_shader", 681, [681]);
Clazz.defineEnumConstant(c$, "excl_display_lists_shaders", 682, [682]);
Clazz.defineEnumConstant(c$, "dash_use_shader", 683, [683]);
Clazz.defineEnumConstant(c$, "dash_as_cylinders", 684, [684]);
Clazz.defineEnumConstant(c$, "nonbonded_use_shader", 685, [685]);
Clazz.defineEnumConstant(c$, "nonbonded_as_cylinders", 686, [686]);
Clazz.defineEnumConstant(c$, "cylinders_shader_filter_faces", 687, [687]);
Clazz.defineEnumConstant(c$, "nb_spheres_size", 688, [688]);
Clazz.defineEnumConstant(c$, "nb_spheres_quality", 689, [689]);
Clazz.defineEnumConstant(c$, "nb_spheres_use_shader", 690, [690]);
Clazz.defineEnumConstant(c$, "render_as_cylinders", 691, [691]);
Clazz.defineEnumConstant(c$, "alignment_as_cylinders", 692, [692]);
Clazz.defineEnumConstant(c$, "cartoon_nucleic_acid_as_cylinders", 693, [693]);
Clazz.defineEnumConstant(c$, "cgo_shader_ub_flags", 694, [694]);
Clazz.defineEnumConstant(c$, "offscreen_rendering_for_antialiasing", 695, [695]);
Clazz.defineEnumConstant(c$, "offscreen_rendering_multiplier", 696, [696]);
Clazz.defineEnumConstant(c$, "cylinder_shader_ff_workaround", 697, [697]);
Clazz.defineEnumConstant(c$, "surface_color_smoothing", 698, [698]);
Clazz.defineEnumConstant(c$, "surface_color_smoothing_threshold", 699, [699]);
Clazz.defineEnumConstant(c$, "dot_use_shader", 700, [700]);
Clazz.defineEnumConstant(c$, "dot_as_spheres", 701, [701]);
Clazz.defineEnumConstant(c$, "ambient_occlusion_mode", 702, [702]);
Clazz.defineEnumConstant(c$, "ambient_occlusion_scale", 703, [703]);
Clazz.defineEnumConstant(c$, "ambient_occlusion_smooth", 704, [704]);
Clazz.defineEnumConstant(c$, "smooth_half_bonds", 705, [705]);
Clazz.defineEnumConstant(c$, "anaglyph_mode", 706, [706]);
Clazz.defineEnumConstant(c$, "edit_light", 707, [707]);
Clazz.defineEnumConstant(c$, "suspend_undo", 708, [708]);
Clazz.defineEnumConstant(c$, "suspend_undo_atom_count", 709, [709]);
Clazz.defineEnumConstant(c$, "bg_image_filename", 710, [712]);
Clazz.defineEnumConstant(c$, "bg_image_mode", 711, [713]);
Clazz.defineEnumConstant(c$, "bg_image_tilesize", 712, [714]);
Clazz.defineEnumConstant(c$, "bg_image_linear", 713, [715]);
Clazz.defineEnumConstant(c$, "label_placement_offset", 714, [718]);
Clazz.defineEnumConstant(c$, "dump_binary", 715, [749]);
});
;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
